@@ -1,6 +1,9 @@
 from ._extensions import *
 from ._patches import *
 from .bboxes import *
+from .checkpoints import *
+from .configs import *
+from .debug import *
 from .iters import *
 from .registries import *
 from .status import *
